@@ -1,3 +1,8 @@
+r'''
+Copy using scp.
+
+(c) Tom de Geus, 2021, MIT
+'''
 
 from .external import exec_cmd
 
